@@ -219,8 +219,9 @@ gboolean area_edit(area_edit_t *area) {
   context.dialog = gtk_dialog_new_with_buttons(
 	  _("Area editor"),
 	  GTK_WINDOW(area->parent), GTK_DIALOG_MODAL,
+	  GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, 
           GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
-	  GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, NULL);
+          NULL);
 
 #ifdef USE_HILDON
   //  gtk_window_set_default_size(GTK_WINDOW(context.dialog), 640, 100);
