@@ -110,5 +110,7 @@ void canvas_image_move(canvas_item_t *item, gint x, gint y,
 		       float hscale, float vscale);
 
 gint canvas_item_get_segment(canvas_item_t *item, gint x, gint y);
+void canvas_item_get_segment_pos(canvas_item_t *item, gint seg,
+				 gint *x0, gint *y0, gint *x1, gint *y1);
 
 #endif // CANVAS_H
