@@ -146,7 +146,23 @@ static void diff_save_relations(relation_t *relation, xmlNodePtr root_node) {
 	    ref = g_strdup_printf("%ld", member->relation->id);
 	    break;
 
+	    /* XXX_ID's are used if this is a reference to an item not */
+	    /* stored in this xml data set */
+	  case NODE_ID:
+	    xmlNewProp(node_member, BAD_CAST "type", BAD_CAST "node");
+	    ref = g_strdup_printf("%ld", member->id);
+	    break;
+	  case WAY_ID:
+	    xmlNewProp(node_member, BAD_CAST "type", BAD_CAST "way");
+	    ref = g_strdup_printf("%ld", member->id);
+	    break;
+	  case RELATION_ID:
+	    xmlNewProp(node_member, BAD_CAST "type", BAD_CAST "relation");
+	    ref = g_strdup_printf("%ld", member->id);
+	    break;
+
 	  default:
+	    printf("unexpected member type %d\n", member->type);
 	    break;
 	  }
 
@@ -189,6 +205,12 @@ gboolean diff_is_clean(osm_t *osm, gboolean honor_hidden_flags) {
     way = way->next;
   }
 
+  relation_t *relation = osm->relation;
+  while(relation && clean) {
+    if(relation->flags) clean = FALSE;
+    relation = relation->next;
+  }
+
   return clean;
 }
 
