@@ -20,7 +20,9 @@
 #include "appdata.h"
 
 static void on_info_clicked(GtkButton *button, gpointer data) {
-  info_dialog((appdata_t*)data);
+  appdata_t *appdata = (appdata_t*)data;
+
+  info_dialog(GTK_WIDGET(appdata->window), appdata, NULL);
 }
 
 static void on_node_add_clicked(GtkButton *button, gpointer data) {
@@ -90,8 +92,7 @@ void icon_bar_map_item_selected(appdata_t *appdata,
   gtk_widget_set_sensitive(iconbar->info, selected);
   gtk_widget_set_sensitive(iconbar->trash, selected);
 
-  if(iconbar->relation_add)
-    gtk_widget_set_sensitive(iconbar->relation_add, selected);
+  gtk_widget_set_sensitive(iconbar->relation_add, selected);
 
   if(selected && map_item && map_item->type == MAP_TYPE_WAY) {
     gtk_widget_set_sensitive(iconbar->way_node_add, TRUE);
@@ -103,12 +104,15 @@ void icon_bar_map_item_selected(appdata_t *appdata,
 }
 
 /* if a user action is on progress, then disable all buttons that */
-/* cause an action to take place */
+/* cause an action to take place or interfere with the action */
 void icon_bar_map_action_idle(appdata_t *appdata, gboolean idle) {
   gint i;
   GtkWidget *action_widgets[] = {
+    appdata->iconbar->trash,
+    appdata->iconbar->info,
     appdata->iconbar->node_add,
     appdata->iconbar->way_add,
+    appdata->iconbar->relation_add,
     NULL
   };
 
@@ -191,7 +195,7 @@ GtkWidget *iconbar_new(appdata_t *appdata) {
 			      on_way_node_add_clicked);
   iconbar->way_cut = tool_add(toolbar, appdata, "way_cut", 
 			      on_way_cut_clicked);
-#if 0
+#if 1
   /* -------------------------------------------------------- */
   gtk_toolbar_insert(GTK_TOOLBAR(toolbar), gtk_separator_tool_item_new(),-1);
 
