@@ -144,8 +144,9 @@ static gboolean tag_edit(tag_context_t *context) {
 
   GtkWidget *dialog = gtk_dialog_new_with_buttons(_("Edit Tag"),
 	  GTK_WINDOW(context->dialog), GTK_DIALOG_MODAL,
+	  GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, 
           GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
-	  GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, NULL);
+          NULL);
 
   gtk_dialog_set_default_response(GTK_DIALOG(dialog), 
 				  GTK_RESPONSE_ACCEPT);
@@ -435,8 +436,8 @@ void info_dialog(GtkWidget *parent, appdata_t *appdata, relation_t *relation) {
 
   context->dialog = gtk_dialog_new_with_buttons(str,
 	  GTK_WINDOW(parent), GTK_DIALOG_MODAL,
-	  GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, 
 	  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, 
+	  GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, 
 	  NULL);
   g_free(str);
 
