@@ -328,8 +328,9 @@ static tag_t *presets_item_dialog(GtkWindow *parent,
   printf("dialog for item %s\n", item->name);
   GtkWidget *dialog = gtk_dialog_new_with_buttons(
 	  item->name, parent, GTK_DIALOG_MODAL,
+	  GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, 
           GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
-	  GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, NULL);
+          NULL);
 
   /* build dialog from items widget list */
   presets_widget_t *widget = item->widget;
