@@ -120,7 +120,7 @@ void map_edit_way_add_segment(map_t *map, gint x, gint y) {
 #endif
   } else {
     
-    /* use the existing node if one was touched */
+    /* use the existing node if one was touched */    
     node_t *node = map_hl_touchnode_get_node(map);
     if(node) {
       printf("  re-using node #%ld\n", node->id);
@@ -169,6 +169,10 @@ void map_edit_way_add_segment(map_t *map, gint x, gint y) {
       }
       
     } else {
+      /* the current way doesn't end on another way if we are just placing */
+      /* a new node */
+      map->action.ends_on = NULL;
+
       if(!osm_position_within_bounds(map->appdata->osm, x, y)) 
 	map_outside_error(map->appdata);
       else 
@@ -306,6 +310,13 @@ void map_edit_way_add_ok(map_t *map) {
     osm_way_attach(map->appdata->osm, map->action.way);
   }
 
+  /* we might already be working on the "ends_on" way as we may */
+  /* be extending it. Joining the same way doesn't make sense. */
+  if(map->action.ends_on && (map->action.ends_on == map->action.way)) {
+    printf("  the new way ends on itself -> don't join itself\n");
+    map->action.ends_on = NULL;
+  }
+
   if(map->action.ends_on) 
     if(!yes_no_f(GTK_WIDGET(map->appdata->window), 
 		 map->appdata, MISC_AGAIN_ID_EXTEND_WAY_END, 0,
@@ -633,10 +644,6 @@ void map_edit_node_move(appdata_t *appdata, map_item_t *map_item,
   /* check if it was dropped onto another node */
   node_t *touchnode = map_hl_touchnode_get_node(map);
   if(touchnode) {
-    /* use touchnodes position */
-    node->lpos = touchnode->lpos;
-    node->pos = touchnode->pos;
-
     map_hl_touchnode_clear(map);
 
     printf("  dropped onto node #%ld\n", touchnode->id);
@@ -650,6 +657,10 @@ void map_edit_node_move(appdata_t *appdata, map_item_t *map_item,
       /* the touchnode vanishes and is replaced by the node the */
       /* user dropped onto it */
 
+      /* use touchnodes position */
+      node->lpos = touchnode->lpos;
+      node->pos = touchnode->pos;
+
       way_t *way = appdata->osm->way;
       while(way) {
 	node_chain_t *chain = way->node_chain;
