@@ -20,6 +20,7 @@
 #ifndef MAP_EDIT_H
 #define MAP_EDIT_H
 
+void map_edit_way_add_begin(map_t *map, way_t *way_sel);
 void map_edit_way_add_segment(map_t *map, gint x, gint y);
 void map_edit_way_add_cancel(map_t *map);
 void map_edit_way_add_ok(map_t *map);
@@ -31,5 +32,7 @@ void map_edit_way_node_add(map_t *map, gint x, gint y);
 void map_edit_way_cut_highlight(map_t *map, map_item_t *item, gint x, gint y);
 void map_edit_way_cut(map_t *map, gint x, gint y);
 
+void map_edit_node_move(appdata_t *appdata, map_item_t *map_item, 
+			gint ex, gint ey);
 
 #endif // MAP_EDIT_H
