@@ -20,7 +20,7 @@
 #ifndef MAP_HL_H
 #define MAP_HL_H
 
-void map_hl_cursor_draw(map_t *map, gint x, gint y);
+void map_hl_cursor_draw(map_t *map, gint x, gint y, gboolean is_world, gint radius);
 void map_hl_cursor_clear(map_t *map);
 
 void map_hl_touchnode_draw(map_t *map, node_t *node);
@@ -35,6 +35,7 @@ canvas_item_t *map_hl_circle_new(map_t *map, canvas_group_t group, map_item_t *m
 
 canvas_item_t *map_hl_polyline_new(map_t *map, canvas_group_t group, map_item_t *map_item, 
 				   canvas_points_t *points, gint width, canvas_color_t color);
+void map_hl_segment_draw(map_t *map, gint width, gint x0, gint y0, gint x1, gint y1);
 
 
 
