@@ -713,8 +713,9 @@ void osm_upload(appdata_t *appdata, osm_t *osm, project_t *project) {
 
   GtkWidget *dialog = gtk_dialog_new_with_buttons(_("Upload to OSM"),
 	  GTK_WINDOW(appdata->window), GTK_DIALOG_MODAL,
+	  GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, 
           GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
-	  GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, NULL);
+	  NULL);
 
   GtkWidget *table = gtk_table_new(4, 5, TRUE); 
 
