@@ -487,8 +487,9 @@ project_t *project_new(select_context_t *context) {
   /* --------------  first choose a name for the project --------------- */
   GtkWidget *dialog = gtk_dialog_new_with_buttons(_("Project name"),
 	  GTK_WINDOW(context->dialog), GTK_DIALOG_MODAL,
+	  GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, 
           GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
-	  GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, NULL);
+	  NULL);
 
   GtkWidget *hbox = gtk_hbox_new(FALSE, 8);
   gtk_box_pack_start_defaults(GTK_BOX(hbox), gtk_label_new(_("Name:")));
@@ -728,8 +729,9 @@ char *project_select(appdata_t *appdata) {
   /* create project selection dialog */
   context->dialog = gtk_dialog_new_with_buttons(_("Project selection"),
 	  GTK_WINDOW(appdata->window), GTK_DIALOG_MODAL,
+	  GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, 
           GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
-	  GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, NULL);
+          NULL);
 
 #ifdef USE_HILDON
   gtk_window_set_default_size(GTK_WINDOW(context->dialog), 500, 300);
@@ -902,8 +904,9 @@ gboolean project_edit(GtkWidget *parent, project_t *project POS_PARM) {
   context->area_edit.parent = 
     context->dialog = gtk_dialog_new_with_buttons(str,
 	  GTK_WINDOW(parent), GTK_DIALOG_MODAL,
+	  GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, 
           GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
-	  GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, NULL);
+          NULL);
   g_free(str);
 
 #ifdef USE_HILDON
