@@ -121,15 +121,28 @@ static void relation_add_item(GtkWidget *parent,
   }
 
   /* ------------------ role dialog ---------------- */
-  printf("role dialog!\n");
-
   GtkWidget *dialog = gtk_dialog_new_with_buttons(_("Select role"),
 	  GTK_WINDOW(parent), GTK_DIALOG_MODAL,
+	  GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, 
           GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
-	  GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, NULL);
+	  NULL);
 
   gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_ACCEPT);
 
+  char *type = osm_tag_get_by_key(relation->tag, "type");
+
+  char *info_str = NULL;
+  if(type) info_str = g_strdup_printf(_("In relation of type: %s"), type);
+  else     info_str = g_strdup_printf(_("In relation #%ld"), relation->id);
+  gtk_box_pack_start_defaults(GTK_BOX(GTK_DIALOG(dialog)->vbox), 
+			      gtk_label_new(info_str));
+  g_free(info_str);
+
+  char *name = osm_tag_get_by_key(relation->tag, "name");
+  if(name) 
+    gtk_box_pack_start_defaults(GTK_BOX(GTK_DIALOG(dialog)->vbox), 
+				gtk_label_new(name));
+
   GtkWidget *hbox = gtk_hbox_new(FALSE, 8);
   gtk_box_pack_start_defaults(GTK_BOX(hbox), gtk_label_new(_("Role:")));
 
@@ -191,7 +204,8 @@ static void relation_add_item(GtkWidget *parent,
     (*memberP)->relation = item->relation;
     break;
   default:
-    g_assert((item->type == NODE)||(item->type == WAY)||(item->type == RELATION));
+    g_assert((item->type == NODE)||(item->type == WAY)||
+	     (item->type == RELATION));
     break;
   }
 
@@ -427,8 +441,8 @@ void relation_add_dialog(appdata_t *appdata, relation_item_t *relitem) {
   
   context->dialog = gtk_dialog_new_with_buttons(str,
 	GTK_WINDOW(appdata->window), GTK_DIALOG_MODAL,
-	GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, 
 	GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, 
+	GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, 
 	NULL);
   g_free(str);
   
